<?php

namespace Drupal\instapage\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\instapage\Api;
use GuzzleHttp\Client;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Handles instapage paths.
 *
 * @package Drupal\instapage\Controller
 */
class PageDisplayController extends ControllerBase {

  /**
   * Http client service.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * Instapage api url.
   *
   * @var string
   */
  protected $endpoint;

  /**
   * Current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected $request;

  /**
   * PageDisplayController constructor.
   *
   * @param \Drupal\instapage\Api $api
   *   Instapage api service.
   * @param \GuzzleHttp\Client $client
   *   Http client service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request
   *   Request stack service.
   */
  public function __construct(Api $api, Client $client, RequestStack $request) {
    $this->endpoint = $api::ENDPOINT;
    $this->request = $request->getCurrentRequest();
    $this->httpClient = $client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('instapage.api'),
      $container->get('http_client'),
      $container->get('request_stack')
    );
  }

  /**
   * Returns the page HTML.
   *
   * @param string $instapage_id
   *   Instapage id.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Page response.
   */
  public function content($instapage_id) {
    $params = '?' . $this->request->getQueryString();
    $url = $this->endpoint . '/server/view-by-id/' . $instapage_id . $params;
    $data = $this->httpClient->get($url)->getBody()->getContents();

    return Response::create($data, 200);
  }

}
